@@ -11,10 +11,10 @@ def UpdatePbar(self, MainWindow, app, value, label):
 	app.processEvents()
 
 
-class ShowCAPTCHA(QtGui.QDialog, Ui_DialogCaptcha):
+class ShowCAPTCHA(QDialog, Ui_DialogCaptcha):
 	def __init__(self, win_parent = None):
 		#Init the base class
-		QtGui.QDialog.__init__(self, win_parent)
+		QDialog.__init__(self, win_parent)
 		self.ui = Ui_DialogCaptcha()
 		self.ui.setupUi(self)
 
@@ -247,8 +247,8 @@ class provider_o2online_de(provider):
 				#current_url = brw.geturl()
 				#base_url = current_url[:current_url.rfind("/")]
 				#dl_captcha = urllib2.urlopen("%s/jcaptchaReg" %(base_url))
-				#qimg = QtGui.QImage.fromData(dl_captcha.read())
-				#pixmap = QtGui.QPixmap.fromImage(qimg)
+				#qimg = QImage.fromData(dl_captcha.read())
+				#pixmap = QPixmap.fromImage(qimg)
 
 				## Download the CAPTCHA with urllib2 and save to jpg
 				#current_url = brw.geturl()
@@ -257,14 +257,14 @@ class provider_o2online_de(provider):
 				#captcha = open("captcha.jpg", 'wb')
 				#captcha.write(dl_captcha.read())
 				#captcha.close()
-				#pixmap = QtGui.QPixmap('captcha.jpg')
+				#pixmap = QPixmap('captcha.jpg')
 
 				## Download CAPTCHA with mechanize
 				current_url = brw.geturl()
 				base_url = current_url[:current_url.rfind("/")]
 				dl_captcha = brw.open("%s/jcaptchaReg" %(base_url)).read(4096*10)
-				qimg = QtGui.QImage.fromData(dl_captcha)
-				pixmap = QtGui.QPixmap.fromImage(qimg)
+				qimg = QImage.fromData(dl_captcha)
+				pixmap = QPixmap.fromImage(qimg)
 				brw.back()
 
 				## Download CAPTCHA with mechanize and save to file
@@ -274,7 +274,7 @@ class provider_o2online_de(provider):
 				#captcha = open("captcha.jpg", 'wb')
 				#captcha.write(dl_captcha)
 				#captcha.close()
-				#pixmap = QtGui.QPixmap('captcha.jpg')
+				#pixmap = QPixmap('captcha.jpg')
 
 				#Set captcha.jpg to show up in the CAPTCHA dialog
 				sc.ui.label_captcha.setPixmap(pixmap)
@@ -296,8 +296,8 @@ class provider_o2online_de(provider):
 
 				result = brw.response().read()
 				if re_cap.search(str(result)):
-					reply = QtGui.QMessageBox.question(MainWindow, 'CAPTCHA verifikation fehlgeschlagen!', "Nochmal versuchen?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
-					if reply == QtGui.QMessageBox.No:
+					reply = QMessageBox.question(MainWindow, 'CAPTCHA verifikation fehlgeschlagen!', "Nochmal versuchen?", QMessageBox.Yes, QMessageBox.No)
+					if reply == QMessageBox.No:
 						STATUS = False
 						MSG = "CAPTCHA verifikation abgebrochen durch User"
 						return STATUS, MSG
