@@ -2,8 +2,9 @@
 # -*- coding: utf-8 -*-
 
 import sys, re, mechanize, base64, urllib2, time, calendar
-from www2sms_gui_dialog_captcha import *
 from PyQt4 import QtCore, QtGui
+from PyQt4.QtGui import QApplication, QDialog, QImage, QPixmap
+from www2sms_gui_dialog_captcha import Ui_DialogCaptcha
 
 def UpdatePbar(self, MainWindow, app, value, label):
 	MainWindow.Stat.ui.label.setText(label)
@@ -11,15 +12,17 @@ def UpdatePbar(self, MainWindow, app, value, label):
 	app.processEvents()
 
 
-class ShowCAPTCHA(QtGui.QDialog, Ui_DialogCaptcha):
+class ShowCAPTCHA(QDialog, Ui_DialogCaptcha):
 	def __init__(self, win_parent = None):
 		#Init the base class
-		QtGui.QDialog.__init__(self, win_parent)
+		QDialog.__init__(self, win_parent)
 		self.ui = Ui_DialogCaptcha()
 		self.ui.setupUi(self)
 
 def error(self, MainWindow, exception, user_msg):
 	# Just for error handling stuff.
+	# When this module exits with "True" the user will see a notification with user_msg
+	# If this module exits with anything but "True" the user will see a warning with user_msg
 	MainWindow.Stat.close()
 	return exception, user_msg
 
@@ -95,11 +98,13 @@ class provider_o2online_de(provider):
 	def num_regexp(self, num):
 		# Remove everything except numbers and "+"
 		num = re.sub(r'[^(0-9)|\+]', '', num)
+		num = re.sub(r'^0{1}', '+49', num)
+		num = re.sub(r'^0{2}', '+', num)
 		# Check if the number matches either +491732332 or 01732332
-		if re.match('^(\+[1-9][0-9]+)|(0[0-9]+)', num):
+		if re.match('^(\+[1-9][0-9]+)', num):
 			return True, num, 'Valid Number'
 		else:
-			return False, num, 'Invalid formated number'
+			return False, num, 'Invalid formated number,'
 
 	# check for CAPTCHA
 	def check_captcha(self, response):
@@ -113,8 +118,8 @@ class provider_o2online_de(provider):
 			#current_url = br.geturl()
 			#base_url = current_url[:current_url.rfind("/")]
 			#dl_captcha = urllib2.urlopen("%s/jcaptchaReg" %(base_url))
-			#qimg = QtGui.QImage.fromData(dl_captcha.read())
-			#pixmap = QtGui.QPixmap.fromImage(qimg)
+			#qimg = QImage.fromData(dl_captcha.read())
+			#pixmap = QPixmap.fromImage(qimg)
 
 			## Download the CAPTCHA with urllib2 and save to jpg
 			#current_url = br.geturl()
@@ -123,14 +128,14 @@ class provider_o2online_de(provider):
 			#captcha = open("captcha.jpg", 'wb')
 			#captcha.write(dl_captcha.read())
 			#captcha.close()
-			#pixmap = QtGui.QPixmap('captcha.jpg')
+			#pixmap = QPixmap('captcha.jpg')
 
 			## Download CAPTCHA with mechanize
 			current_url = self.br.geturl()
 			base_url = current_url[:current_url.rfind("/")]
 			dl_captcha = br.open("%s/jcaptchaReg" %(base_url)).read(4096*10)
-			qimg = QtGui.QImage.fromData(dl_captcha)
-			pixmap = QtGui.QPixmap.fromImage(qimg)
+			qimg = QImage.fromData(dl_captcha)
+			pixmap = QPixmap.fromImage(qimg)
 			self.br.back()
 
 			## Download CAPTCHA with mechanize and save to file
@@ -140,7 +145,7 @@ class provider_o2online_de(provider):
 			#captcha = open("captcha.jpg", 'wb')
 			#captcha.write(dl_captcha)
 			#captcha.close()
-			#pixmap = QtGui.QPixmap('captcha.jpg')
+			#pixmap = QPixmap('captcha.jpg')
 
 			#Set captcha.jpg to show up in the CAPTCHA dialog
 			sc.ui.label_captcha.setPixmap(pixmap)
@@ -158,8 +163,8 @@ class provider_o2online_de(provider):
 
 			response = self.br.response().read()
 			if self.re_cap.search(str(response)):
-				reply = QtGui.QMessageBox.question(MainWindow, 'CAPTCHA verifikation fehlgeschlagen!', "Nochmal versuchen?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
-				if reply == QtGui.QMessageBox.No:
+				reply = QMessageBox.question(MainWindow, 'CAPTCHA verifikation fehlgeschlagen!', "Nochmal versuchen?", QMessageBox.Yes, QMessageBox.No)
+				if reply == QMessageBox.No:
 					return error(self, MainWindow, False, 'CAPTCHA verifikation abgebrochen durch User')
 
 	def get_advanced_setting(self, MainWindow):
@@ -204,6 +209,8 @@ class provider_o2online_de(provider):
 			re_fail = re.compile('(Fehler beim Login)|(Error logging in)', re.IGNORECASE)
 			# RegExp to find the link to the SMS center:
 			re_meino2 = re.compile('meino2')
+			# RegExp to find remaining FREE SMS:
+			re_free = re.compile('Frei-SMS: [0-9]+')
 
 			# Instanziate a Browser
 			UpdatePbar(self, MainWindow, app, "1", "Initiating the browser")
@@ -322,6 +329,10 @@ class provider_o2online_de(provider):
 				response = br.response().read()
 			except Exception, e:
 				return error(self, MainWindow, e, 'Failed to open the SMS-Center')
+
+			# Find how much FREE SMS we have left.
+			FREESMS = re_free.findall(response)[0].split()[1]
+
 			# Select the SMS-Form
 			try:
 				br.select_form(name='frmSMS')
@@ -331,9 +342,12 @@ class provider_o2online_de(provider):
 			# Fill the forms
 			UpdatePbar(self, MainWindow, app, "10", "Fill the forms")
 			br.form.set_all_readonly(False)
-			# FIll in number an SMS-Text
+			# FIll in number
 			br.form['SMSTo'] = NUMBER
-			br.form['SMSText'] = SMSTEXT
+			# Convert the "unicode" string obtained from the QSTRING to "str"
+			# Otherwise mechanize will bail out with:
+			# UnicodeEncodeError: 'ascii' codec can't encode characters in position
+			br.form['SMSText'] = SMSTEXT.encode('utf-8')
 			# Check for FlashSMS
 			if FLASH :
 				br.form['FlagFlash'] = '1'
@@ -444,7 +458,7 @@ class provider_vodafone_nl(provider):
 		try:
 			br.select_form(name='controle')
 			br.form['phoneNumber'] = number
-			br.form['body'] = SMSTEXT
+			br.form['body'] = SMSTEXT.encode('utf-8')
 			br.submit()
 		except:
 			print response
